@@ -1,3 +1,4 @@
+from functools import partial
 import torch
 from torch import nn
 from vector_quantize_pytorch.vector_quantize_pytorch import VectorQuantize
@@ -18,10 +19,10 @@ class ResidualVQ(nn.Module):
             return
 
         first_vq, *rest_vq = self.layers
-        codebook = first_vq._codebook.embed
+        codebook = first_vq._codebook
 
         for vq in rest_vq:
-            vq._codebook.embed = codebook
+            vq._codebook = codebook
 
     def forward(self, x):
         quantized_out = 0.
@@ -38,5 +39,5 @@ class ResidualVQ(nn.Module):
             all_indices.append(indices)
             all_losses.append(loss)
 
-        all_losses, all_indices = map(torch.stack, (all_losses, all_indices))
+        all_losses, all_indices = map(partial(torch.stack, dim = -1), (all_losses, all_indices))
         return quantized_out, all_indices, all_losses
